# coding: utf-8

"""
    backend

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from reportr_backend_client.models.paginated_news_response import PaginatedNewsResponse

class TestPaginatedNewsResponse(unittest.TestCase):
    """PaginatedNewsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedNewsResponse:
        """Test PaginatedNewsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedNewsResponse`
        """
        model = PaginatedNewsResponse()
        if include_optional:
            return PaginatedNewsResponse(
                page = 56,
                page_size = 56,
                total_pages = 56,
                total_items = 56,
                news = [
                    reportr_backend_client.models.news_item.NewsItem(
                        published_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        provider = '', 
                        news_item_id = '', 
                        headline = '', 
                        subheadline = '', 
                        author = '', 
                        country = '', 
                        city = '', 
                        region = '', 
                        word_count = 56, 
                        content = '', 
                        media = [
                            ''
                            ], 
                        topics = [
                            ''
                            ], )
                    ]
            )
        else:
            return PaginatedNewsResponse(
                page = 56,
                page_size = 56,
                total_pages = 56,
                total_items = 56,
                news = [
                    reportr_backend_client.models.news_item.NewsItem(
                        published_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        provider = '', 
                        news_item_id = '', 
                        headline = '', 
                        subheadline = '', 
                        author = '', 
                        country = '', 
                        city = '', 
                        region = '', 
                        word_count = 56, 
                        content = '', 
                        media = [
                            ''
                            ], 
                        topics = [
                            ''
                            ], )
                    ],
        )
        """

    def testPaginatedNewsResponse(self):
        """Test PaginatedNewsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
