# coding: utf-8

"""
    backend

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from reportr_backend_client.models.news_item import NewsItem

class TestNewsItem(unittest.TestCase):
    """NewsItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NewsItem:
        """Test NewsItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NewsItem`
        """
        model = NewsItem()
        if include_optional:
            return NewsItem(
                published_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                provider = '',
                news_item_id = '',
                headline = '',
                subheadline = '',
                author = '',
                country = '',
                city = '',
                region = '',
                word_count = 56,
                content = '',
                media = [
                    ''
                    ],
                topics = [
                    ''
                    ]
            )
        else:
            return NewsItem(
                published_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                provider = '',
                news_item_id = '',
                headline = '',
                author = '',
                country = '',
                content = '',
        )
        """

    def testNewsItem(self):
        """Test NewsItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
